Get a Model Configuration from the Registry (Internal)
Source:R/model_registry.R
get_model_config.RdRetrieves the configuration for a specified model and validates that it exists.
R/model_registry.R
get_model_config.RdRetrieves the configuration for a specified model and validates that it exists.