View source: R/apply_missing.R
| apply_missing | R Documentation |
Takes a complete response matrix and introduces missingness according to the study specification.
apply_missing(data, study, seed = NULL, theta = NULL)
data |
Numeric matrix (N x n_items). Complete response data. |
study |
An |
seed |
Integer. Random seed for reproducibility. |
theta |
Optional numeric vector of length |
Numeric matrix of same dimensions as data, with NA values
introduced according to the missingness mechanism.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.